@@ -59,7 +59,6 @@ class MVNMixtureModel():
             "eta":torch.tensor(1).float()}
         self._autoguide = False
         self._enumer = "parallel"
-        self._init_seed = [randint(1,1000) for _ in range(2)]
 
         if len(self.dimensions) == 0:
             self.dimensions = [str(_) for _ in range(self._T)]
@@ -86,7 +85,7 @@ class MVNMixtureModel():
 
 
     def filter_dataset(self, min_cov=0, n=None, min_ccf=.05, k_interval=(5,25),
-            metric="calinski_harabasz_score", random_state=25):
+            metric="calinski_harabasz_score", seed=25):
         '''
         Function to filter the input dataset.
         - `min_cov` -> hard threshold for each observation. Only the observations with at least a 
@@ -99,7 +98,7 @@ class MVNMixtureModel():
         with the centroid of all timepoints below `5%` of the sum of centroids for all the timepoints.
         - `k_interval` -> interval of `K` values to look for the best `K`.
         - `metric` -> metric used to retrieve the best `K`, among `calinski_harabasz_score` and `silhouette`.
-        - `random_state` -> seed value.
+        - `seed` -> seed value.
         '''
 
         idxs = torch.any(self.dataset >= min_cov, dim=1)
@@ -108,11 +107,11 @@ class MVNMixtureModel():
         finally: self.dataset = self.dataset[idxs,]
         
         self.dataset, self.IS = self._filter_dataframe_init(min_ccf=min_ccf,
-            k_interval=k_interval, metric=metric, random_state=random_state)
+            k_interval=k_interval, metric=metric, seed=seed)
 
         if n is not None:  # takes a random sample from the dataset
             n = min(n, self.dataset.shape[0])
-            np.random.seed(random_state)
+            np.random.seed(seed)
             idx = np.random.randint(self.dataset.shape[0], size=n)
             try: self.IS = self.IS[idx]
             finally: self.dataset = self.dataset[idx,:]
@@ -147,7 +146,7 @@ class MVNMixtureModel():
 
 
     def _filter_dataframe_init(self, min_ccf=.05, k_interval=(5,15), \
-            metric="calinski_harabasz_score", random_state=25):
+            metric="calinski_harabasz_score", seed=25):
         '''
         Function to filter the input dataset according to the centroid the clusters output
         from a KMeans, with `K` being the best `K` in `k_interval` according to `metric`.
@@ -158,11 +157,11 @@ class MVNMixtureModel():
         with the centroid of all timepoints below `5%` of the sum of centroids for all the timepoints.
         - `k_interval` -> interval of `K` values to look for the best `K`.
         - `metric` -> metric used to retrieve the best `K`, among `calinski_harabasz_score` and `silhouette`.
-        - `random_state` -> seed value.
+        - `seed` -> seed value.
         '''
 
         index_fn = self._find_index_function(metric)
-        N, K = self.dataset.shape[0], self._find_best_k(k_interval=k_interval, index_fn=index_fn, random_state=random_state)
+        N, K = self.dataset.shape[0], self._find_best_k(k_interval=k_interval, index_fn=index_fn, seed=seed)
 
         duplicated_rows, duplicated_idx, counts_cum = self.check_input_kmeans()
 
@@ -203,7 +202,7 @@ class MVNMixtureModel():
             return sklearn.metrics.silhouette_score
 
 
-    def _find_best_k(self, k_interval=(5,20), index_fn=sklearn.metrics.calinski_harabasz_score, random_state=25):
+    def _find_best_k(self, k_interval=(5,20), index_fn=sklearn.metrics.calinski_harabasz_score, seed=25):
         k_min = min(max(k_interval[0], 2), self.dataset.unique().shape[0]-1)
         k_max = min(k_interval[1], self.dataset.unique().shape[0]-1)
 
@@ -216,7 +215,7 @@ class MVNMixtureModel():
         
         scores = torch.zeros(k_interval[1])
         for k in range(k_interval[0], k_interval[1]):
-            km = KMeans(n_clusters=k, random_state=random_state)
+            km = KMeans(n_clusters=k, random_state=seed)
             labels = km.fit_predict(self.dataset)
             real_k = len(np.unique(labels))
             scores[real_k] = max(scores[real_k], index_fn(self.dataset, labels))
@@ -268,7 +267,7 @@ class MVNMixtureModel():
         '''
         if not self._autoguide:
             def guide_expl():
-                params = self._initialize_params(random_state=self._seed)
+                params = self._initialize_params(seed=self._seed)
                 N, K = params["N"], params["K"]
                 min_var = self.hyperparameters["min_var"]
 
@@ -326,8 +325,8 @@ class MVNMixtureModel():
         return Sigma
 
 
-    def _initialize_centroids(self, K, N, random_state):
-        km = KMeans(n_clusters=K, random_state=random_state).fit(self.dataset)
+    def _initialize_centroids(self, K, N, seed):
+        km = KMeans(n_clusters=K, random_state=seed).fit(self.dataset)
         self.init_params["clusters"] = torch.from_numpy(km.labels_)
         
         # init the mixing proportions
@@ -335,10 +334,10 @@ class MVNMixtureModel():
         self.init_params["weights"] = w.float().detach()
 
         # add gaussian noise to the centroids and reset too low values
-        pyro.set_rng_seed(self._init_seed[0])
+        pyro.set_rng_seed(self._init_seed)
 
         ctrs = torch.tensor(km.cluster_centers_).float().detach() + \
-            torch.abs(torch.normal(0, 100, (K, self._T)))
+            torch.abs(torch.normal(0, 10, (K, self._T)))
 
         pyro.set_rng_seed(self._seed)
 
@@ -357,8 +356,10 @@ class MVNMixtureModel():
             var_constr[cl,:] = ctrs[cl,:] * self.lm["slope"] + self.lm["intercept"]
 
         # add gaussian noise to the variance
-        pyro.set_rng_seed(self._init_seed[1])
-        var += torch.abs(torch.normal(0, 100, (K, self._T)))
+        pyro.set_rng_seed(self._init_seed)
+
+        var += torch.abs(torch.normal(0, 10, (K, self._T)))
+        
         pyro.set_rng_seed(self._seed)
 
         # reset variance contraints and variance values
@@ -391,7 +392,7 @@ class MVNMixtureModel():
         return sigma_chol
 
 
-    def _initialize_params(self, random_state=25):
+    def _initialize_params(self, seed=25):
         '''
         Function to initialize the parameters.
         It performs a K-means clustering and define the initial weights 
@@ -401,7 +402,7 @@ class MVNMixtureModel():
         if not self.init_params["is_computed"]:
             N, K = self.params["N"], self.params["K"]
 
-            ctrs = self._initialize_centroids(K, N, random_state)
+            ctrs = self._initialize_centroids(K, N, seed)
             var, var_constr = self._initialize_variance(K, ctrs)
             sigma_chol = self._initialize_sigma_chol(K)
             Sigma = self.compute_Sigma(sigma_chol=sigma_chol, sigma_vector=var, K=K)
@@ -419,7 +420,7 @@ class MVNMixtureModel():
 
     def fit(self, steps=500, optim_fn=pyro.optim.Adam, lr=0.005, cov_type="full", \
             loss_fn=pyro.infer.TraceEnum_ELBO(), convergence=True, initializ=True, \
-            min_steps=1, p=.5, random_state=25, store_params=False, show_progr=True):
+            min_steps=1, p=1, store_params=False, show_progr=True, seed=25, init_seed=10):
         
         pyro.enable_validation(True)
         pyro.get_param_store().__init__()
@@ -428,8 +429,8 @@ class MVNMixtureModel():
         self._is_trained = False
         self._max_iter = steps
         self.cov_type = cov_type
-        self._seed = random_state
-        # self._init_seed = randint(1,1000)
+        self._seed = seed
+        self._init_seed = init_seed
 
         if self._seed is not None:
             pyro.set_rng_seed(self._seed)
